@@ -1,9 +1,9 @@
 <?php
 /**
  * Functions used by ldapquery plugin.
- * @copyright 2005 SquirrelMail Project Team
+ * @copyright 2005-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: functions.php,v 1.9 2005/03/20 12:14:38 tokul Exp $
+ * @version $Id: functions.php,v 1.15 2006/04/10 06:13:04 tokul Exp $
  * @package sm-plugins
  * @subpackage ldapquery
  */
@@ -20,11 +20,9 @@ if (!defined('SM_PATH'))  {
 include_once(SM_PATH . 'plugins/ldapquery/class.schema.php');
 
 /* load forms.php */
-if (file_exists(SM_PATH . 'functions/forms.php')) {
-    include_once(SM_PATH . 'functions/forms.php');
-} else {
-    include_once(SM_PATH . 'plugins/ldapquery/forms.php');
-}
+include_once(SM_PATH . 'functions/forms.php');
+/* error_box() function */
+include_once(SM_PATH . 'functions/display_messages.php');
 
 global $ldq_authreqd, $ldq_attributes, $ldq_searchobjs, $ldq_searchattrs, $ldq_allow_asterisk_search, $ldq_debug;
 /* load default config */
@@ -52,6 +50,8 @@ array_walk($ldq_attributes,'ldq_arraytolower');
 array_walk($ldq_searchobjs,'ldq_arraytolower');
 array_walk($ldq_searchattrs,'ldq_arraytolower');
 
+/** array callback functions */
+
 /**
  * lowercase elements of array
  * callback function
@@ -63,6 +63,17 @@ function ldq_arraytolower(&$value,&$key) {
     $key=strtolower($key);
 }
 
+/**
+ * trim values of array
+ * callback function
+ * @param string $value array value
+ * @param string $key array key
+ * @since 2.1
+ */
+function ldq_arraytrim(&$value,&$key) {
+    $value=trim($value);
+}
+
 /* internal functions for setup.php */
 
 /**
@@ -71,7 +82,7 @@ function ldq_arraytolower(&$value,&$key) {
  * @return string version info
  */
 function ldapquery_version_function() {
-    return '2.0';
+    return '2.1';
 }
 
 /**
@@ -483,7 +494,7 @@ function ldapquery_abook_form($entry,$smallsize=true) {
     if (isset($entry['mail']) || isset($entry['email']) || isset($entry['rfc822mailbox'])) {
         $ret.= "<!-- start abook form -->\n";
         // start form
-        $ret.= addForm(sqm_baseuri() . 'src/addressbook.php');
+        $ret.= addForm(sqm_baseuri() . 'plugins/ldapquery/addressbook.php');
         // add nickname field (remove all spaces from entries)
         if (isset($entry['commonname']['count']) && $entry['commonname']['count']>0 && isset($entry['commonname'][0])) {
             $ret.= addHidden('addaddr[nickname]',str_replace(' ','_',$entry['commonname'][0]));
@@ -523,8 +534,18 @@ function ldapquery_abook_form($entry,$smallsize=true) {
             // use labeleduri
             $ret.= addHidden('addaddr[label]',$entry['labeleduri'][0]);
         } elseif (isset($entry['phone']['count']) && $entry['phone']['count']>0 && isset($entry['phone'][0])) {
-            // use labeleduri
+            // use phone
             $ret.= addHidden('addaddr[label]',$entry['phone'][0]);
+        } elseif (isset($entry['telephonenumber']['count']) && 
+                  $entry['telephonenumber']['count']>0 && 
+                  isset($entry['telephonenumber'][0])) {
+            // use telephonenumber
+            $ret.= addHidden('addaddr[label]',$entry['telephonenumber'][0]);
+        } elseif (isset($entry['mobile']['count']) && 
+                  $entry['mobile']['count']>0 && 
+                  isset($entry['mobile'][0])) {
+            // use mobile
+            $ret.= addHidden('addaddr[label]',$entry['mobile'][0]);
         } else {
             $ret.= addHidden('addaddr[label]','');
         }
@@ -533,6 +554,9 @@ function ldapquery_abook_form($entry,$smallsize=true) {
         } else {
             $ret.= addSubmit(_("Add to address book"));
         }
+        // save search
+        $ret.= ldq_hidden_search_fields();
+
         $ret.= "</form>\n";
         $ret.= "<!-- end abook form -->\n";
     } else {
@@ -540,4 +564,79 @@ function ldapquery_abook_form($entry,$smallsize=true) {
     }
     return $ret;
 }
+
+/**
+ * Checks if SquirrelMail configuration and PHP setup are correct.
+ * @return string error message or empty string.
+ * @since 2.1
+ */
+function ldq_check_setup() {
+    global $ldap_server;
+
+    if (!extension_loaded('ldap')) {
+        return _("Plugin requires PHP with LDAP support.");
+    } elseif (empty($ldap_server)) {
+        return _("LDAP address books are not configured in SquirrelMail configuration.");
+    }
+    return '';
+}
+
+/**
+ * Creates hidden form fields from POST data
+ * @return string
+ * @since 2.1
+ */
+function ldq_hidden_search_fields() {
+    $ret = '';
+    if (sqgetGlobalVar('ldq_searchfor',$ldq_searchfor,SQ_POST)) {
+        $ret.= addHidden('ldq_searchfor',$ldq_searchfor);
+    }
+    if (sqgetGlobalVar('ldq_searchby',$ldq_searchby,SQ_POST)) {
+        $ret.= addHidden('ldq_searchby',$ldq_searchby);
+    }
+    if (sqgetGlobalVar('ldq_comparetype',$ldq_comparetype,SQ_POST)) {
+        $ret.= addHidden('ldq_comparetype',$ldq_comparetype);
+    }
+    if (sqgetGlobalVar('ldq_querystr',$ldq_querystr,SQ_POST)) {
+        $ret.= addHidden('ldq_querystr',$ldq_querystr);
+    }
+    if (sqgetGlobalVar('ldq_sortby',$ldq_sortby,SQ_POST)) {
+        $ret.= addHidden('ldq_sortby',$ldq_sortby);
+    }
+    if (sqgetGlobalVar('ldq_rdn',$ldq_rdn,SQ_POST)) {
+        $ret.= addHidden('ldq_rdn',$ldq_rdn);
+    }
+    if (sqgetGlobalVar('ldq_pass',$ldq_pass,SQ_POST)) {
+        $ret.= addHidden('ldq_pass',$ldq_pass);
+    }
+    if (sqgetGlobalVar('ldq_server',$ldq_server,SQ_POST)) {
+        $ldq_server = (int) $ldq_server;
+        $ret.= addHidden('ldq_server',$ldq_server);
+    }
+    return $ret;
+}
+
+/**
+ * Wrapper arround standard error_box function.
+ *
+ * Function is used to create error boxes that are centered and
+ * does not take whole page width. It also takes switches gettext 
+ * domains before calling error_box() function.
+ * @since 2.1
+ */
+function ldq_error_box($sError) {
+    global $color;
+
+    // switch to squirrelmail domain
+    bindtextdomain('squirrelmail',SM_PATH . 'locale');
+    textdomain('squirrelmail');
+
+    echo '<table align="center"><tr><td>';
+    error_box($sError,$color);
+    echo '</td></tr></table>';
+
+    // switch to ldapquery domain
+    bindtextdomain('ldapquery',SM_PATH . 'locale');
+    textdomain('ldapquery');
+}
 ?>
\ No newline at end of file
