@@ -2,9 +2,9 @@
 /**
  * ldapquery options
  * @copyright 2001-2004 Brent Bice <bbice@persistence.com>
- * @copyright 2004-2005 SquirrelMail Project Team
+ * @copyright 2004-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: options.php,v 1.9 2005/03/01 09:22:11 tokul Exp $
+ * @version $Id: options.php,v 1.12 2006/03/21 17:21:10 tokul Exp $
  * @package sm-plugins
  * @subpackage ldapquery
  */
@@ -27,6 +27,14 @@ displayPageHeader($color, "None");
 bindtextdomain('ldapquery',SM_PATH . 'locale');
 textdomain('ldapquery');
 
+$ldq_check = ldq_check_setup();
+if (! empty($ldq_check)) {
+    bindtextdomain('squirrelmail',SM_PATH . 'locale');
+    textdomain('squirrelmail');
+    error_box($ldq_check,$color);
+    exit('</body></html>');
+}
+
 $ldq_loaded_schemas=ldq_load_schemas();
 
 echo "<br />\n"
