@@ -2,21 +2,13 @@
 /**
  * ldapquery plugin - setup script
  * @copyright 2001-2004 Brent Bice <bbice@persistence.com>
- * @copyright 2004-2005 SquirrelMail Project Team
+ * @copyright 2004-2006 The SquirrelMail Project Team
  * @license http://opensource.org/licenses/gpl-license.php GNU Public License
- * @version $Id: setup.php,v 1.7 2005/03/01 09:22:11 tokul Exp $
+ * @version $Id: setup.php,v 1.9 2006/03/21 17:21:10 tokul Exp $
  * @package sm-plugins
  * @subpackage ldapquery
  */
 
-/**
- * SM_PATH define
- * @ignore
- */
-if (!defined('SM_PATH'))  {
-    define('SM_PATH','../../');
-}
-
 /**
  * Init plugin
  */
